"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdminClient = void 0;
const workflows_1 = require("../../protoc/workflows");
const hatchet_error_1 = __importDefault(require("../../util/errors/hatchet-error"));
const logger_1 = require("../../util/logger");
const retrier_1 = require("../../util/retrier");
/**
 * AdminClient is a client for interacting with the Hatchet Admin API. This allows you to configure, trigger,
 * and monitor workflows.
 * The admin client can be accessed via:
 * ```typescript
 * const hatchet = Hatchet.init()
 * const admin = hatchet.admin as AdminClient;
 *
 * // Now you can use the admin client to interact with the Hatchet Admin API
 * admin.list_workflows().then((res) => {
 *   res.rows?.forEach((row) => {
 *     console.log(row);
 *   });
 * });
 * ```
 */
class AdminClient {
    constructor(config, channel, factory, api, tenantId) {
        this.config = config;
        this.client = factory.create(workflows_1.WorkflowServiceDefinition, channel);
        this.api = api;
        this.tenantId = tenantId;
        this.logger = new logger_1.Logger(`Admin`, config.log_level);
    }
    /**
     * Creates a new workflow or updates an existing workflow. If the workflow already exists, Hatchet will automatically
     * determine if the workflow definition has changed and create a new version if necessary.
     * @param workflow a workflow definition to create
     */
    put_workflow(workflow) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield (0, retrier_1.retrier)(() => __awaiter(this, void 0, void 0, function* () { return this.client.putWorkflow({ opts: workflow }); }), this.logger);
            }
            catch (e) {
                throw new hatchet_error_1.default(e.message);
            }
        });
    }
    /**
     * Run a new instance of a workflow with the given input. This will create a new workflow run and return the ID of the
     * new run.
     * @param workflowName the name of the workflow to run
     * @param input an object containing the input to the workflow
     * @returns the ID of the new workflow run
     */
    run_workflow(workflowName, input) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const inputStr = JSON.stringify(input);
                const resp = yield this.client.triggerWorkflow({
                    name: workflowName,
                    input: inputStr,
                });
                return resp.workflowRunId;
            }
            catch (e) {
                throw new hatchet_error_1.default(e.message);
            }
        });
    }
    /**
     * List workflows in the tenant associated with the API token.
     * @returns a list of all workflows in the tenant
     */
    list_workflows() {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.api.workflowList(this.tenantId);
            return res.data;
        });
    }
    /**
     * Get a workflow by its ID.
     * @param workflowId the workflow ID (**note:** this is not the same as the workflow version id)
     * @returns
     */
    get_workflow(workflowId) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.api.workflowGet(workflowId);
            return res.data;
        });
    }
    /**
     * Get a workflow version.
     * @param workflowId the workflow ID
     * @param version the version of the workflow to get. If not provided, the latest version will be returned.
     * @returns the workflow version
     */
    get_workflow_version(workflowId, version) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.api.workflowVersionGet(workflowId, {
                version,
            });
            return res.data;
        });
    }
    /**
     * Get a workflow run.
     * @param workflowRunId the id of the workflow run to get
     * @returns the workflow run
     */
    get_workflow_run(workflowRunId) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.api.workflowRunGet(this.tenantId, workflowRunId);
            return res.data;
        });
    }
    /**
     * List workflow runs in the tenant associated with the API token.
     * @param query the query to filter the list of workflow runs
     * @returns
     */
    list_workflow_runs(query) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.api.workflowRunList(this.tenantId, query);
            return res.data;
        });
    }
    /**
     * Schedule a workflow to run at a specific time or times.
     * @param workflowId the ID of the workflow to schedule
     * @param options an object containing the schedules to set
     */
    schedule_workflow(workflowId, options) {
        try {
            this.client.scheduleWorkflow({
                workflowId,
                schedules: options === null || options === void 0 ? void 0 : options.schedules,
            });
        }
        catch (e) {
            throw new hatchet_error_1.default(e.message);
        }
    }
}
exports.AdminClient = AdminClient;
